@@ -1,26 +1,51 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Heuristic::META;
-BEGIN {
-  $Path::IsDev::Heuristic::META::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Heuristic::META::VERSION = '1.000001';
-}
+$Path::IsDev::Heuristic::META::VERSION = '1.001000';
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 # ABSTRACT: Determine if a path contains META.(json|yml)
 
-use Role::Tiny::With;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Role::Tiny::With qw( with );
 with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
+
+
+
+
+
+
+
+
 sub files {
   return qw( META.json META.yml );
 }
 
 
+
+
+
+
+
 sub matches {
   my ( $self, $result_object ) = @_;
   if ( $self->child_exists_any_file( $result_object, $self->files ) ) {
@@ -44,7 +69,7 @@ Path::IsDev::Heuristic::META - Determine if a path contains META.(json|yml)
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -79,7 +104,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
