@@ -1,25 +1,52 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Heuristic::Makefile;
-BEGIN {
-  $Path::IsDev::Heuristic::Makefile::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Heuristic::Makefile::VERSION = '1.000001';
-}
+$Path::IsDev::Heuristic::Makefile::VERSION = '1.001000';
 
 
-# ABSTRACT: Determine if a path contains a C<Makefile>
-use Role::Tiny::With;
+
+
+
+
+
+
+
+
+
+
+
+
+
+# ABSTRACT: Determine if a path contains a Makefile
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Role::Tiny::With qw( with );
 with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
+
+
+
+
+
+
+
+
+
 sub files {
   return qw( GNUmakefile makefile Makefile );
 }
 
 
+
+
+
+
+
 sub matches {
   my ( $self, $result_object ) = @_;
   if ( $self->child_exists_any_file( $result_object, $self->files ) ) {
@@ -39,11 +66,11 @@ __END__
 
 =head1 NAME
 
-Path::IsDev::Heuristic::Makefile - Determine if a path contains a C<Makefile>
+Path::IsDev::Heuristic::Makefile - Determine if a path contains a Makefile
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -79,7 +106,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
