@@ -1,27 +1,54 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Heuristic::TestDir;
-BEGIN {
-  $Path::IsDev::Heuristic::TestDir::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Heuristic::TestDir::VERSION = '1.000001';
-}
-
+$Path::IsDev::Heuristic::TestDir::VERSION = '1.001000';
 # ABSTRACT: Determine if a path contains a t/ or xt/ directory
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
-use Role::Tiny::With;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Role::Tiny::With qw( with );
 
 with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::Dir';
 
 
+
+
+
+
+
+
+
+
 sub dirs {
   return qw( xt t );
 }
 
 
+
+
+
+
+
+
+
 sub matches {
   my ( $self, $result_object ) = @_;
   if ( $self->child_exists_any_dir( $result_object, $self->dirs ) ) {
@@ -45,7 +72,7 @@ Path::IsDev::Heuristic::TestDir - Determine if a path contains a t/ or xt/ direc
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -82,7 +109,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
