@@ -1,24 +1,48 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Heuristic::Tool::MakeMaker;
-BEGIN {
-  $Path::IsDev::Heuristic::Tool::MakeMaker::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Heuristic::Tool::MakeMaker::VERSION = '1.000001';
-}
+$Path::IsDev::Heuristic::Tool::MakeMaker::VERSION = '1.001000';
 
 
-# ABSTRACT: Determine if a path is an C<EUMM> Tooled source directory
+
+
+
+
+
+
+
+
+
+
+
+
+
+# ABSTRACT: Determine if a path is an ExtUtils::MakeMaker Tooled source directory
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Role::Tiny::With qw( with );
 with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::File';
 
 
+
+
+
+
+
+
+
 sub files { return qw( Makefile.PL ) }
 
 
+
+
+
+
+
 sub matches {
   my ( $self, $result_object ) = @_;
   if ( $self->child_exists_any_file( $result_object, $self->files ) ) {
@@ -38,11 +62,11 @@ __END__
 
 =head1 NAME
 
-Path::IsDev::Heuristic::Tool::MakeMaker - Determine if a path is an C<EUMM> Tooled source directory
+Path::IsDev::Heuristic::Tool::MakeMaker - Determine if a path is an ExtUtils::MakeMaker Tooled source directory
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -76,7 +100,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
