@@ -1,25 +1,49 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Heuristic::VCS::Git;
-BEGIN {
-  $Path::IsDev::Heuristic::VCS::Git::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Heuristic::VCS::Git::VERSION = '1.000001';
-}
+$Path::IsDev::Heuristic::VCS::Git::VERSION = '1.001000';
 
 
-# ABSTRACT: Determine if a path contains a C<.git> repository
 
-use Role::Tiny::With;
+
+
+
+
+
+
+
+
+
+
+
+
+# ABSTRACT: Determine if a path contains a .git repository
+
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Role::Tiny::With qw( with );
 
 with 'Path::IsDev::Role::Heuristic', 'Path::IsDev::Role::Matcher::Child::Exists::Any::Dir';
 
 
+
+
+
+
+
+
+
 sub dirs { return qw( .git ) }
 
 
+
+
+
+
+
 sub matches {
   my ( $self, $result_object ) = @_;
   if ( $self->child_exists_any_dir( $result_object, $self->dirs ) ) {
@@ -39,11 +63,11 @@ __END__
 
 =head1 NAME
 
-Path::IsDev::Heuristic::VCS::Git - Determine if a path contains a C<.git> repository
+Path::IsDev::Heuristic::VCS::Git - Determine if a path contains a .git repository
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -77,7 +101,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
