@@ -1,17 +1,14 @@
-
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::NegativeHeuristic::HomeDir;
-BEGIN {
-  $Path::IsDev::NegativeHeuristic::HomeDir::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::NegativeHeuristic::HomeDir::VERSION = '1.000001';
-}
-
+$Path::IsDev::NegativeHeuristic::HomeDir::VERSION = '1.001000';
 # ABSTRACT: User home directories are not development roots
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 ## no critic (RequireArgUnpacking, ProhibitSubroutinePrototypes)
 sub _uniq (@) {
   my %seen = ();
@@ -19,24 +16,56 @@ sub _uniq (@) {
 }
 
 
-use Role::Tiny::With;
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+use Role::Tiny::With qw( with );
 with 'Path::IsDev::Role::NegativeHeuristic', 'Path::IsDev::Role::Matcher::FullPath::Is::Any';
 
-sub _fhd { require File::HomeDir; return 'File::HomeDir' }
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 sub paths {
   my @sources;
-  push @sources, _fhd()->my_home;
-  push @sources, _fhd()->my_desktop;
-  push @sources, _fhd()->my_music;
-  push @sources, _fhd()->my_pictures;
-  push @sources, _fhd()->my_videos;
-  push @sources, _fhd()->my_data;
+  require File::HomeDir;
+  push @sources, File::HomeDir->my_home;
+  for my $method (qw( my_home my_desktop my_music my_pictures my_videos my_data )) {
+    if ( $File::HomeDir::IMPLEMENTED_BY->can($method) ) {
+      push @sources, File::HomeDir->$method();
+    }
+  }
   return _uniq grep { defined and length } @sources;
 }
 
 
+
+
+
+
+
 sub excludes {
   my ( $self, $result_object ) = @_;
   return unless $self->fullpath_is_any( $result_object, $self->paths );
@@ -56,7 +85,7 @@ Path::IsDev::NegativeHeuristic::HomeDir - User home directories are not developm
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -96,7 +125,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
