@@ -1,27 +1,42 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp;
-BEGIN {
-  $Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp::VERSION = '1.000001';
-}
-
+$Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp::VERSION = '1.001000';
 # ABSTRACT: Match when a path has a child file matching an expression
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+
+
+
+
+
+
+
+
+
+
 
 use Role::Tiny;
 
 
+
+
+
+
+
+
+
 sub _this_child_matchregexp {
   my ( $self, $result_object, $child, $regexp ) = @_;
   my $ctx = {
     'child'          => "$child",
     'child_basename' => $child->basename,
     expression       => $regexp,
-    tests            => []
+    tests            => [],
   };
   my $tests = $ctx->{tests};
 
@@ -36,6 +51,17 @@ sub _this_child_matchregexp {
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
 sub child_basename_matchregexp {
   my ( $self, $result_object, $regexp ) = @_;
   for my $child ( $result_object->path->children ) {
@@ -58,7 +84,7 @@ Path::IsDev::Role::Matcher::Child::BaseName::MatchRegexp - Match when a path has
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -96,7 +122,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
