@@ -1,20 +1,35 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Path::IsDev::Role::Matcher::Child::Exists::Any;
-BEGIN {
-  $Path::IsDev::Role::Matcher::Child::Exists::Any::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Path::IsDev::Role::Matcher::Child::Exists::Any::VERSION = '1.000001';
-}
-
+$Path::IsDev::Role::Matcher::Child::Exists::Any::VERSION = '1.001000';
 # ABSTRACT: Match if any of a list of children exists
 
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
 use Role::Tiny;
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub child_exists {
   my ( $self, $result_object, $child ) = @_;
 
@@ -34,6 +49,13 @@ sub child_exists {
 }
 
 
+
+
+
+
+
+
+
 sub child_exists_any {
   my ( $self, $result_object, @children ) = @_;
   for my $child (@children) {
@@ -56,7 +78,7 @@ Path::IsDev::Role::Matcher::Child::Exists::Any - Match if any of a list of child
 
 =head1 VERSION
 
-version 1.000001
+version 1.001000
 
 =head1 METHODS
 
@@ -88,7 +110,7 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2014 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
